// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KIRIGAMIPLATFORM_VERSION_H
#define KIRIGAMIPLATFORM_VERSION_H

#define KIRIGAMIPLATFORM_VERSION_STRING "6.23.1"
#define KIRIGAMIPLATFORM_VERSION_MAJOR 6
#define KIRIGAMIPLATFORM_VERSION_MINOR 23
#define KIRIGAMIPLATFORM_VERSION_PATCH 1
#define KIRIGAMIPLATFORM_VERSION ((6<<16)|(23<<8)|(1))

#endif
